# PaymentMethodSnapshotResponse


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**account_id** | **str** | The ID of the customer account associated with this payment method. | [optional] 
**ach_aba_code** | **str** | The nine-digit routing number or ABA number used by banks. Applicable to ACH payment methods. | [optional] 
**ach_account_name** | **str** | The name of the account holder, which can be either a person or a company. Applicable to ACH payment methods. | [optional] 
**ach_account_number_mask** | **str** | This is a masked displayable version of the ACH account number, used for security purposes. For example: &#x60;XXXXXXXXX54321&#x60;. | [optional] 
**ach_account_type** | [**GetPaymentMethodSnapshotResponseAchAccountType**](GetPaymentMethodSnapshotResponseAchAccountType.md) |  | [optional] 
**ach_bank_name** | **str** | The name of the bank where the ACH payment account is held. | [optional] 
**bank_branch_code** | **str** | The branch code of the bank used for direct debit. | [optional] 
**bank_check_digit** | **str** | The check digit in the international bank account number, which confirms the validity of the account. Applicable to direct debit payment methods. | [optional] 
**bank_city** | **str** | The city of the direct debit bank. | [optional] 
**bank_code** | **str** | The sort code or number that identifies the bank. This is also known as the sort code. | [optional] 
**bank_identification_number** | **str** | The first six or eight digits of the payment method&#39;s number, such as the credit card number or account number. Banks use this number to identify a payment method. | [optional] 
**bank_name** | **str** | The name of the direct debit bank. | [optional] 
**bank_postal_code** | **str** | The zip code or postal code of the direct debit bank. | [optional] 
**bank_street_name** | **str** | The name of the street of the direct debit bank. | [optional] 
**bank_street_number** | **str** | The number of the direct debit bank. | [optional] 
**bank_transfer_account_name** | **str** | The name on the direct debit bank account. | [optional] 
**bank_transfer_account_number_mask** | **str** | This is a masked displayable version of the bank account number, used for security purposes. For example: &#x60;XXXXXXXXX54321&#x60;. | [optional] 
**bank_transfer_account_type** | **str** | The type of the customer&#39;s bank account. Applicable to direct debit payment methods. | [optional] 
**bank_transfer_type** | [**GetPaymentMethodSnapshotResponseBankTransferType**](GetPaymentMethodSnapshotResponseBankTransferType.md) |  | [optional] 
**business_identification_code** | **str** | The business identification code for Swiss direct payment methods that use the Global Collect payment gateway. Only applicable to direct debit payments in Switzerland with Global Collect. | [optional] 
**city** | **str** | The city of the customer&#39;s address. Applicable to debit payment methods. | [optional] 
**company_name** | **str** | The name of the company.  | [optional] 
**country** | **str** | The two-letter country code of the customer&#39;s address. Applicable to direct debit payment methods. | [optional] 
**credit_card_address1** | **str** | The first line of the card holder&#39;s address, which is often a street address or business name. Applicable to credit card and direct debit payment methods. | [optional] 
**credit_card_address2** | **str** | The second line of the card holder&#39;s address. Applicable to credit card and direct debit payment methods. | [optional] 
**credit_card_city** | **str** | The city of the card holder&#39;s address. Applicable to credit card and direct debit payment methods. | [optional] 
**credit_card_country** | **str** | The country of the card holder&#39;s address. | [optional] 
**credit_card_expiration_month** | **int** | The expiration month of the credit card or debit card. Applicable to credit card and direct debit payment methods. | [optional] 
**credit_card_expiration_year** | **int** | The expiration month of the credit card or debit card. Applicable to credit card and direct debit payment methods. | [optional] 
**credit_card_holder_name** | **str** | The full name of the card holder. Applicable to credit card and direct debit payment methods. | [optional] 
**credit_card_mask_number** | **str** | A masked version of the credit or debit card number. | [optional] 
**credit_card_postal_code** | **str** | The billing address&#39;s zip code. | [optional] 
**credit_card_state** | **str** | The billing address&#39;s state. Applicable if &#x60;CreditCardCountry&#x60; is either Canada or the US. | [optional] 
**credit_card_type** | [**ProxyGetPaymentMethodSnapshotCreditCardType**](ProxyGetPaymentMethodSnapshotCreditCardType.md) |  | [optional] 
**device_session_id** | **str** | The session ID of the user when the &#x60;PaymentMethod&#x60; was created or updated. | [optional] 
**email** | **str** | An email address for the payment method in addition to the bill to contact email address. | [optional] 
**existing_mandate** | [**PaymentMethodMandateInfoMandateStatus**](PaymentMethodMandateInfoMandateStatus.md) |  | [optional] 
**first_name** | **str** | The customer&#39;s first name. Only applicable to direct debit payment methods. | [optional] 
**iban** | **str** | The International Bank Account Number. Only applicable to direct debit payment methods. | [optional] 
**ip_address** | **str** | The IP address of the user when the payment method was created or updated. | [optional] 
**id** | **str** | Object identifier. | [optional] 
**identity_number** | **str** | The unique identity number of the customer account.   | [optional] 
**is_company** | **bool** | Whether the customer account is a company.  | [optional] 
**last_failed_sale_transaction_date** | **datetime** | The date of the last failed attempt to collect payment with this payment method. | [optional] 
**last_name** | **str** | The customer&#39;s last name. Only applicable to direct debit payment methods. | [optional] 
**last_transaction_date_time** | **datetime** | The date of the most recent transaction. | [optional] 
**last_transaction_status** | **str** | The status of the most recent transaction. | [optional] 
**mandate_creation_date** | **date** | The date when the mandate was created, in &#x60;yyyy-mm-dd&#x60; format. A mandate is a signed authorization for UK and NL customers. Only applicable to direct debit payment methods. | [optional] 
**mandate_id** | **str** | The ID of the mandate. A mandate is a signed authorization for UK and NL customers. Only applicable to direct debit payment methods. | [optional] 
**mandate_received** | **str** | Indicates if  the mandate was received. A mandate is a signed authorization for UK and NL customers. Only applicable to direct debit payment methods. | [optional] 
**mandate_update_date** | **date** | The date when the mandate was last updated, in &#x60;yyyy-mm-dd&#x60; format. A mandate is a signed authorization for UK and NL customers. Only applicable to direct debit payment methods. | [optional] 
**max_consecutive_payment_failures** | **int** | The number of allowable consecutive failures Zuora attempts with the payment method before stopping. | [optional] 
**name** | **str** | The name of the payment method. | [optional] 
**num_consecutive_failures** | **int** | The number of consecutive failed payment for the payment method. | [optional] 
**payment_method_id** | **str** | Object identifier of the payment method. | [optional] 
**payment_method_status** | [**GetPaymentMethodSnapshotResponsePaymentMethodStatus**](GetPaymentMethodSnapshotResponsePaymentMethodStatus.md) |  | [optional] 
**payment_retry_window** | **int** | The retry interval setting, which prevents making a payment attempt if the last failed attempt was within the last specified number of hours. | [optional] 
**paypal_baid** | **str** | The PayPal billing agreement ID, which is a contract between two PayPal accounts. | [optional] 
**paypal_email** | **str** | The email address associated with the account holder&#39;s PayPal account or of the PayPal account of the person paying for the service. | [optional] 
**paypal_preapproval_key** | **str** | PayPal&#39;s Adaptive Payments API key. | [optional] 
**paypal_type** | [**GetPaymentMethodSnapshotResponsePaypalType**](GetPaymentMethodSnapshotResponsePaypalType.md) |  | [optional] 
**phone** | **str** | The phone number that the account holder registered with the bank. This field is used for credit card validation when passing to a gateway. | [optional] 
**postal_code** | **str** | The zip code of the customer&#39;s address. Only applicable to direct debit payment methods. | [optional] 
**second_token_id** | **str** | A gateway unique identifier that replaces sensitive payment method data. Applicable to CC Reference Transaction payment methods. | [optional] 
**state** | **str** | The state of the customer&#39;s address. Only applicable to direct debit payment methods. | [optional] 
**street_name** | **str** | The street name of the customer&#39;s address. Only applicable to direct debit payment methods. | [optional] 
**street_number** | **str** | The street number of the customer&#39;s address. Only applicable to direct debit payment methods. | [optional] 
**token_id** | **str** | A gateway unique identifier that replaces sensitive payment method data or represents a gateway&#39;s unique customer profile. Applicable to CC Reference Transaction payment methods. | [optional] 
**total_number_of_error_payments** | **int** | The number of error payments that used this payment method. | [optional] 
**total_number_of_processed_payments** | **int** | The number of successful payments that used this payment method. | [optional] 
**type** | [**PaymentMethodType**](PaymentMethodType.md) |  | [optional] 
**use_default_retry_rule** | **bool** | Determines whether to use the default retry rules configured in the Zuora Payments settings. | [optional] 

## Example

```python
from zuora_sdk.models.payment_method_snapshot_response import PaymentMethodSnapshotResponse

# TODO update the JSON string below
json = "{}"
# create an instance of PaymentMethodSnapshotResponse from a JSON string
payment_method_snapshot_response_instance = PaymentMethodSnapshotResponse.from_json(json)
# print the JSON string representation of the object
print(PaymentMethodSnapshotResponse.to_json())

# convert the object into a dict
payment_method_snapshot_response_dict = payment_method_snapshot_response_instance.to_dict()
# create an instance of PaymentMethodSnapshotResponse from a dict
payment_method_snapshot_response_from_dict = PaymentMethodSnapshotResponse.from_dict(payment_method_snapshot_response_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


